<?php

namespace Drupal\simpleviews\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\views\Views;

/**
 * SimpleViews form list.
 */
class SimpleViewsFormList extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simpleviews_form_list';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    // Display existing views in a table.
    $form['views_table'] = [
      '#type' => 'table',
      '#header' => [
        $this->t('View Label'),
        $this->t('Page URL'),
        $this->t('Operations'),
      ],
      '#empty' => $this->t('No views found.'),
    ];

    // Get a list of all views.
    $views = Views::getEnabledViews();

    // Populate the views table.
    foreach ($views as $view) {
      if (str_starts_with($view->id(), 'simpleviews_')) {
        $form['views_table'][$view->id()] = $this->buildViewFormElements($view);
      }
    }

    return $form;
  }

  /**
   * Helper function to retrieve view elements.
   */
  protected function buildViewFormElements($view) {
    $elements = [
      'view_label' => [
        '#markup' => $view->label(),
      ],
      'page_url' => [
        '#markup' => $this->t('No page URL'),
      ],
      'actions' => [
        '#type' => 'operations',
        '#links' => [
          'edit' => [
            'title' => $this->t('Edit'),
            'url' => Url::fromRoute('simpleviews.form_edit', ['view_id' => $view->id()]),
          ],
          'delete' => [
            'title' => $this->t('Delete'),
            'url' => Url::fromRoute('simpleviews.view_delete', ['view_id' => $view->id()]),
          ],
        ],
      ],
    ];

    // Check if the view has a page display and a path.
    $page_display = $view->getDisplay('page');
    if ($page_display && isset($page_display['display_options']['path'])) {
      $path = $page_display['display_options']['path'];
      $elements['page_url'] = [
        '#type' => 'link',
        '#title' => $path,
        '#url' => Url::fromUri('internal:/' . $path),
      ];
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [];
  }

}
